@@ -3,8 +3,9 @@
 import sys
 import os
 import logging
-from Messenger_new.common.variables import LOGGING_LEVEL
-sys.path.append(os.path.join(os.getcwd(), '../..'))
+sys.path.append('../')
+from common.variables import LOGGING_LEVEL
+
 
 
 # создаём формировщик логов (formatter):
